Unit Kommando;           { Stellt Objekte zur Kommandozeilenbearbeitung }
{-----------------------------------------------------------------------}

{**************************************************************************}
{*                                                                        *}
{*  UNIT KOMMANDO.PAS - Copyright 1992-2001 by                            *}
{*  *}
{*                        ROSE, Ralph Roth                                *}
{*                        Finkenweg 24                                    *}
{*                        D 78658 Zimmern o.R.                            *}
{*                        http://come.to/rose_swe                         *}
{*                                                                        *}
{*  Stellt ein Objekt zur Verfgung, welches einen intelligenten          *}
{*  Kommandozeilen 'Praser' implementiert. Nhere Beschreibungen siehe    *}
{*  einzelne Funktionen.                                                  *}
{*  *}
{*  Die Funktion SetupVideoModes stellt einen universellen Parser fr     *}
{*  verschiedene Videomodi zur Verfgung. Sie zeigt zugleich die Ver-     *}
{*  wendung des Kommandozeilenobjektes.                                   *}
{*  *}
{*                                                                        *}
{*  Initial Creation    1992                                              *}
{*                                                                        *}
{*  Updates:      21.12.1993  Function IsItem                             *}
{*                13.09.1996  Function GetString (/LOG=xxx)               *}
{*                01.01.1998  AddOption enhanced                          *}
{*                05.07.2000  GetValue: integer -> LongInt                *}
{*                02.01.2001  First fixes for Win32/Linux porting         *}
{*                20.01.2001  Ported to Linux                             *}
{*                06.02.2001  GetValueReal for GetValue                   *}
{*                                                                        *}
{**************************************************************************}

{
$Log: kommando.pas $
Revision 1.4  2001/02/07 23:12:53  rar
GetValueReal added

Revision 1.3  2001/01/21 23:53:03  rar
First working (and bugfixed) version for Linux

Revision 1.2  2001/01/21 16:05:59  rose_p300
Port for Linux, works on DOS, Win32 targets

Revision 1.1  2001/01/21 11:32:16  rose_p300
Initial revision

}

{-------------------------------------------------------DATA------------}

INTERFACE

uses crt, dos, rstrings, r_utils;   { Units einbinden }

Const RCS_ID_KOMMANDO : String [80] =
      '$Header: C:/TP/SRC/RCS/kommando.pas 1.4 2001/02/07 23:12:53 rar Exp $';
{$IFDEF LINUX}
      ParamDelimiterSet : Set of Char = ['-'];
{$ELSE}
      ParamDelimiterSet : Set of Char = ['-','/'];
{$ENDIF}

type                               { Deklaration der Typen }

  TKommandoZeile = object               { Objekt definieren }


     Params      : ^String;             { Kommandozeile        }
     ParamCounter: Byte;                { Anzahl der Parameter }
     ParamStrCounter: Byte;             { Anzahl der NICHT Parameter }
     ToUpper     : Boolean;             { Alle Parameter in Grobuchstaben? }
                                        { vom Typ Privat/Protected! }

     constructor init;          { Liet aus der Kommandozeile und         }
                                { aus der Umgebungsvariable die Parameter }

     Procedure   SetUpper(bFlag : Boolean); { setzt direkt 'toupper' }

     function    IsOption(What: String) : Boolean;
                                { Gibt True zurck, falls /What in der    }
                                { Kommandozeile enthalten ist.            }
     Function    IsItem(What: String) : Boolean;
                                { Gibt True zurck, falls What in der    }
                                { Kommandozeile enthalten ist also z.B.  }
                                { eine Laufwerksoption                   }

     Procedure   AddOption(What: String);
                                { Fgt '/WHAT' zum Objekt hinzu (in Params) }

     Procedure   AddItem(What: String);
                                { Fgt 'WHAT' zum Objekt hinzu (in Params) }

     Function    HasDrives : Boolean;
                                { Gibt True zurck, wenn Laufwerke in }
                                { Params^ enthalten sind/ist.         }

     Function    PartStr( Nr : Byte) : String;
                                { Gibt ParamString[ nr ] zurck.      }
                                { ACHTUNG: Keine Unterscheidung, ob   }
                                { ein Parameter oder ein Dateiname    }
                                { angegeben wurde!                    }

     Function    ParamString( Nr : Byte) : String;
                                { Gibt ParamString[ nr ] zurck,      }
                                { eventuelle Parameter werden         }
                                { berlesen!                          }


     Function    FirstPath : String;
                                { Gibt ersten Path/Pfad/Drive zurck  }

     Function    GetValue( search : string ) : LongInt;
     Function    GetValueReal( search : string ) : Real;
                                { Gibt einen Wert zurck -> /DAUER=10 }
                                { Integer -> LongInt, 01.07.2000 }
                                { LongInt -> Real, 06.02.2001 }

     Function    GetString (search : String) : String;

     destructor  done;          { Gib dyn. Speicherplatz wieder frei  }
  end;

  PKommandoZeile = ^TKommandoZeile;     { Zeiger darauf }


  Function SetupVideoModes: Word;    { liest Kommandozeile und schaltet in }
                                     { die gewhlten Videomodes.  18.02.93 }
                                     { 22.02.93 -- gibt Videomodus zurck  }

  Procedure TestUnitKommando(bUpper : Boolean);
                                     { Function to check all the Parameters }

{-----------------------------------------------------------------------}
IMPLEMENTATION

